@@ -7,13 +7,9 @@ use std::{
 use futures_io::{AsyncBufRead, AsyncRead};
 use futures_lite::ready;
 
-use crate::{
-    decode,
-    immutable::{Band, Text},
-    PacketLine, StreamingPeekableIter, U16_HEX_BYTES,
-};
+use crate::{decode, BandRef, PacketLineRef, StreamingPeekableIter, TextRef, U16_HEX_BYTES};
 
-type ReadLineResult<'a> = Option<std::io::Result<Result<PacketLine<'a>, decode::Error>>>;
+type ReadLineResult<'a> = Option<std::io::Result<Result<PacketLineRef<'a>, decode::Error>>>;
 /// An implementor of [`AsyncBufRead`] yielding packet lines on each call to [`read_line()`][AsyncBufRead::read_line()].
 /// It's also possible to hide the underlying packet lines using the [`Read`][AsyncRead] implementation which is useful
 /// if they represent binary data, like the one of a pack file.
@@ -116,14 +112,14 @@ where
     }
 
     /// Forwards to the parent [StreamingPeekableIter::reset_with()]
-    pub fn reset_with(&mut self, delimiters: &'static [PacketLine<'static>]) {
+    pub fn reset_with(&mut self, delimiters: &'static [PacketLineRef<'static>]) {
         if let State::Idle { ref mut parent } = self.state {
             parent.as_mut().unwrap().reset_with(delimiters)
         }
     }
 
     /// Forwards to the parent [StreamingPeekableIter::stopped_at()]
-    pub fn stopped_at(&self) -> Option<PacketLine<'static>> {
+    pub fn stopped_at(&self) -> Option<PacketLineRef<'static>> {
         match self.state {
             State::Idle { ref parent } => parent.as_ref().unwrap().stopped_at,
             _ => None,
@@ -140,7 +136,7 @@ where
     pub async fn peek_data_line(&mut self) -> Option<std::io::Result<Result<&[u8], crate::decode::Error>>> {
         match self.state {
             State::Idle { ref mut parent } => match parent.as_mut().unwrap().peek_line().await {
-                Some(Ok(Ok(crate::PacketLine::Data(line)))) => Some(Ok(Ok(line))),
+                Some(Ok(Ok(crate::PacketLineRef::Data(line)))) => Some(Ok(Ok(line))),
                 Some(Ok(Err(err))) => Some(Ok(Err(err))),
                 Some(Err(err)) => Some(Err(err)),
                 _ => None,
@@ -238,13 +234,13 @@ where
                                         .map_err(|err| io::Error::new(io::ErrorKind::Other, err))?;
                                     const ENCODED_BAND: usize = 1;
                                     match band {
-                                        Band::Data(d) => break (U16_HEX_BYTES + ENCODED_BAND, d.len()),
-                                        Band::Progress(d) => {
-                                            let text = Text::from(d).0;
+                                        BandRef::Data(d) => break (U16_HEX_BYTES + ENCODED_BAND, d.len()),
+                                        BandRef::Progress(d) => {
+                                            let text = TextRef::from(d).0;
                                             handle_progress(false, text);
                                         }
-                                        Band::Error(d) => {
-                                            let text = Text::from(d).0;
+                                        BandRef::Error(d) => {
+                                            let text = TextRef::from(d).0;
                                             handle_progress(true, text);
                                         }
                                     };
